summaryrefslogtreecommitdiffstats
path: root/src/H5D.c
diff options
context:
space:
mode:
authorMohamad Chaarawi <chaarawi@hdfgroup.org>2012-04-18 21:32:55 (GMT)
committerMohamad Chaarawi <chaarawi@hdfgroup.org>2012-04-18 21:32:55 (GMT)
commitb7a6535650cd0317e3aee1bb62a96664b38e5304 (patch)
treea88c6b8668f76983b9b0acf4cf0a57845c78d110 /src/H5D.c
parent33f70a817aba7a4dd020fb29a187c53ba05e157c (diff)
parenta07c8f924703bdf3d1654b59cabf847f5d0f2683 (diff)
downloadhdf5-b7a6535650cd0317e3aee1bb62a96664b38e5304.zip
hdf5-b7a6535650cd0317e3aee1bb62a96664b38e5304.tar.gz
hdf5-b7a6535650cd0317e3aee1bb62a96664b38e5304.tar.bz2
[svn-r22297] merge from trunk
Diffstat (limited to 'src/H5D.c')
-rw-r--r--src/H5D.c22
1 files changed, 12 insertions, 10 deletions
diff --git a/src/H5D.c b/src/H5D.c
index eae57fb..47178ff 100644
--- a/src/H5D.c
+++ b/src/H5D.c
@@ -20,7 +20,7 @@
#define H5D_PACKAGE /*suppress error about including H5Dpkg */
/* Interface initialization */
-#define H5_INTERFACE_INIT_FUNC H5D_init_pub_interface
+#define H5_INTERFACE_INIT_FUNC H5D__init_pub_interface
/***********/
@@ -47,6 +47,8 @@
/* Local Prototypes */
/********************/
+static herr_t H5D__init_pub_interface(void);
+
/*********************/
/* Package Variables */
@@ -71,9 +73,9 @@ H5FL_BLK_EXTERN(vlen_fl_buf);
/*--------------------------------------------------------------------------
NAME
- H5D_init_pub_interface -- Initialize interface-specific information
+ H5D__init_pub_interface -- Initialize interface-specific information
USAGE
- herr_t H5D_init_pub_interface()
+ herr_t H5D__init_pub_interface()
RETURNS
Non-negative on success/Negative on failure
DESCRIPTION
@@ -82,12 +84,12 @@ DESCRIPTION
--------------------------------------------------------------------------*/
static herr_t
-H5D_init_pub_interface(void)
+H5D__init_pub_interface(void)
{
- FUNC_ENTER_NOAPI_NOINIT
+ FUNC_ENTER_STATIC_NOERR
FUNC_LEAVE_NOAPI(H5D_init())
-} /* H5D_init_pub_interface() */
+} /* H5D__init_pub_interface() */
/*-------------------------------------------------------------------------
@@ -654,7 +656,7 @@ H5Diterate(void *buf, hid_t type_id, hid_t space_id, H5D_operator_t op,
if(!(H5S_has_extent(space)))
HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "dataspace does not have extent set")
- ret_value = H5D_iterate(buf, type_id, space, op, operator_data);
+ ret_value = H5D__iterate(buf, type_id, space, op, operator_data);
done:
FUNC_LEAVE_API(ret_value)
@@ -788,14 +790,14 @@ H5Dvlen_get_buf_size(hid_t dataset_id, hid_t type_id, hid_t space_id,
HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a dataset transfer property list")
/* Set the memory manager to the special allocation routine */
- if(H5P_set_vlen_mem_manager(plist, H5D_vlen_get_buf_size_alloc, &vlen_bufsize, NULL, NULL) < 0)
+ if(H5P_set_vlen_mem_manager(plist, H5D__vlen_get_buf_size_alloc, &vlen_bufsize, NULL, NULL) < 0)
HGOTO_ERROR(H5E_PLIST, H5E_CANTINIT, FAIL, "can't set VL data allocation routine")
/* Set the initial number of bytes required */
vlen_bufsize.size = 0;
- /* Call H5D_iterate with args, etc. */
- ret_value = H5D_iterate(&bogus, type_id, space, H5D_vlen_get_buf_size, &vlen_bufsize);
+ /* Call H5D__iterate with args, etc. */
+ ret_value = H5D__iterate(&bogus, type_id, space, H5D__vlen_get_buf_size, &vlen_bufsize);
/* Get the size if we succeeded */
if(ret_value >= 0)